# Zmeiapi

Zmeiapi является набором программных средств для упрощения и автоматизации 
построения файлов входных данных для кода Serpent. 

Содержит классы для создания материалов, пинов, ячеек, поверхностей 
и задания основной информации для расчетов. Также содержит вспомогательные данные, 
вспомогательные инструменты и классы для обработки данных.